/* playerDef.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef SOUNDFILEPLAYERDEF_H
#define SOUNDFILEPLAYERDEF_H

#include <map>
#include <vector>
#include <string>
#include <iostream.h>
#include <algorithm>
#include <iterator>

// This class encapsulates the user's specification of the command to
// use to play various sound files.

class PlayerDef {
public:
  PlayerDef(const string &play_command, const string &play_status,
	    const string &verify_command, const string &verify_status);
  PlayerDef(const PlayerDef &copy);
  PlayerDef &operator = (const PlayerDef &copy);

  static const PlayerDef *find_def(int type);
  static const PlayerDef *find_def(const string &filename);
  static const PlayerDef *cdrom_def();
  static void read_config();

  enum StatusType {
    ST_literal,
    ST_current_frame,
    ST_frames_remaining,
    ST_total_frames,
    ST_current_time,
    ST_time_remaining,
    ST_total_time,
    ST_current_pos,
    ST_current_percent,
  };
  class StatusEntry {
  public:
    StatusEntry(StatusType type, const string &literal = string());
    void output(ostream &out) const;

    StatusType _type;
    string _literal;
  };
  typedef vector<StatusEntry> Status;

  enum Features {
    F_rstart = 0x001,
    F_rstop  = 0x002,
    F_report = 0x004,
  };

  bool has_feature(int feature_mask) const;

  string get_verify_command(const string &filename, int track_num) const;
  const Status &get_verify_status() const;
  string get_play_command(const string &sound_device,
			  const string &filename, int track_num,
			  double start_time, double end_time, 
			  int total_frames, double total_time) const;
  const Status &get_play_status() const;

private:
  static Status expand_status(const string &status);

  int _features;
  string _verify_command_unexpanded;
  Status _verify_status;
  string _play_command_unexpanded;
  Status _play_status;

  typedef map<int, PlayerDef> DefMap;
  static DefMap _defs;

  typedef map<string, int> ExtensionMap;
  static ExtensionMap _extensions;
  static const PlayerDef *_cdrom_def;
};


inline ostream &operator << (ostream &out, const PlayerDef::StatusEntry &entry) {
  entry.output(out);
  return out;
}

inline ostream &operator << (ostream &out, const PlayerDef::Status &status) {
  copy(status.begin(), status.end(), 
       ostream_iterator<PlayerDef::StatusEntry>(out, " : "));
  return out;
}

#endif
