/* queryResult.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#include "queryResult.h"
#include "database.h"

#include <assert.h>

QueryResultBase::
QueryResultBase(Database &db) : _db(db) {
}

QueryResultBase::
~QueryResultBase() {
}

QueryResult::
QueryResult(QueryResultBase *ptr) : ReferenceCountProxy(ptr) {
}

QueryResult::  
QueryResult(const QueryResult &copy) : ReferenceCountProxy(copy) {
}

QueryResult &QueryResult::
operator = (const QueryResult &copy) {
  ReferenceCountProxy::operator = (copy);
  return *this;
}

bool QueryResult::
success() const {
  return get_ptr()->success();
}

string QueryResult::
get_error_message() const {
  return get_ptr()->get_error_message();
}
  
int QueryResult::
get_num_columns() const {
  return get_ptr()->get_num_columns();
}

string QueryResult::
get_column_name(int c) const {
  return get_ptr()->get_column_name(c);
}

DataCell::Type QueryResult::
get_column_type(int c) const {
  return get_ptr()->get_column_type(c);
}
  
int QueryResult::
get_num_rows() const {
  return get_ptr()->get_num_rows();
}

DataCell QueryResult::
get_cell(int r, int c) const {
  return get_ptr()->get_cell(r, c);
}


QueryResultBase *QueryResult::
get_ptr() const {
  QueryResultBase *ptr = (QueryResultBase *)ReferenceCountProxy::get_ptr();
  assert(ptr != NULL);
  return ptr;
}
